%define ALD_Ver		1.2.1

Name:         curl

License:      Copyright (c) 1996 - 2013, Daniel Stenberg
Summary:      curl is a tool to transfer data from or to a server
Group:        Development/Libraries
Version:      7.32.0
Release:      0

Requires:	rtmpdump-sharedlib

Source: %{name}-%{version}.tar.lzma
Source1: CROSS.sh

%define DestDir		/net

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_build}
%define target_  %{nil}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
curl is a tool to transfer data from or to a server, using one of the supported
protocols (DICT FILE FTP FTPS HTTP HTTPS IMAP IMAPS POP3 POP3S RTMP RTSP 
SMTP SMTPS TELNET TFTP).
The command is designed to work without user interaction.
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel
These libraries are needed to compile C code.
# --------------------------------------
%package devel-man
Summary:      man3 for Libraries
Group:        Development/Libraries
%description devel-man
man3 for Libraries

#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fPIC -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
%if %{_target_cpu} == "armv7l"
OPTFLAGS="-O2 -fPIC -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%else
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif
%endif

%if %{_os} == "mingw"
CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS=" "
%else
CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -std=gnu99"
GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=`case $GCC_VER_STR in \
 4.[56789].*) echo -static-libgcc ;; \
 esac`
LDFLAGS="$LDFLAGS -Wl,--gc-sections"
%endif

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
%if %{_os} == "mingw"
	--disable-shared \
%else
	--enable-shared \
	--disable-static \
%endif
	--disable-debug \
	--disable-curldebug \
	--disable-libtool-lock \
	--enable-http \
	--enable-ftp \
	--enable-file \
	--disable-ldap \
	--enable-rtsp \
	--enable-proxy \
	--enable-dict \
	--enable-telnet \
	--enable-tftp \
	--enable-pop3 \
	--enable-imap \
	--enable-smtp \
	--disable-gopher \
	--disable-manual \
	--disable-sspi \
	--disable-ntlm-wb \
	--disable-tls-srp \
	--disable-soname-bump \
	--with-random=/dev/urandom \
	&>FConfigure_log.txt

#	--disable-crypto-auth 

make &>FMake_log.txt


# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
rm $RPM_BUILD_ROOT%{_libdir}/*.la
cp COPYING README docs/DISTRO-DILEMMA docs/FAQ docs/FEATURES docs/HTTP-COOKIES docs/MAIL-ETIQUETTE docs/MANUAL $RPM_BUILD_ROOT%{docdir}/

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%if %{BUILD_LOCAL_CROSS}
mkdir $RPM_BUILD_ROOT%{csysbindir}
mv $RPM_BUILD_ROOT%{cross_bindir}/curl-config $RPM_BUILD_ROOT%{csysbindir}/
rm -r $RPM_BUILD_ROOT%{cross_bindir}
rm -r $RPM_BUILD_ROOT%{cross_mandir}
rm $RPM_BUILD_ROOT%{cross_docdir}/FAQ $RPM_BUILD_ROOT%{cross_docdir}/FEATURES $RPM_BUILD_ROOT%{cross_docdir}/HTTP-COOKIES $RPM_BUILD_ROOT%{cross_docdir}/MAIL-ETIQUETTE $RPM_BUILD_ROOT%{cross_docdir}/MANUAL
%endif #BUILD_LOCAL_CROSS
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if (%{_os} == "mingw")
  rm %{name}-$SE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
  mv %{name}-devel-man-$SE $DD/%{name}-devel-man-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%Files
%{_prefix}

%if %{BUILD_LOCAL_CROSS}
%Files %{TO_ARCH}
%{csysdir}
%endif #!BUILD_LOCAL_CROSS
%else  #mingw

%Files
%{_bindir}
%{_libdir}/*.so.*
%{_mandir}/man1
%{docdir}

%Files devel
%{_includedir}
%{_libdir}/*.so
%{_libdir}/pkgconfig

%files devel-man
%{_mandir}/man3

%if %{BUILD_LOCAL_CROSS}

%Files %{TO_ARCH}
%{csysbindir}/curl-config
%{cross_libdir}/*.so.*
%{cross_libdir}/*.so
%{cross_libdir}/pkgconfig
%{cross_includedir}
%{cross_docdir}

%endif #!BUILD_LOCAL_CROSS
%endif #!mingw
